pub fn validate_buffer_compatibility(
input: &[i16],
output: &[u8],
compression_ratio: f32,
) -> Result<()>Expand description
Validate that two buffers have compatible sizes for processing
Errors
Returns an error when output is smaller than the size implied by the
input length and compression_ratio.