validate_channel_alignment

Function validate_channel_alignment 

pub fn validate_channel_alignment(samples: &[i16], channels: u8) -> Result<()>
Validate that frame samples are properly aligned for multi-channel audio

Errors

Returns an error when the sample count is not divisible by channels.