pub fn validate_channel_alignment(samples: &[i16], channels: u8) -> Result<()>Expand description
Validate that frame samples are properly aligned for multi-channel audio
Errors
Returns an error when the sample count is not divisible by channels.