validate_g722_frame

Function validate_g722_frame 

pub fn validate_g722_frame(
    samples: &[i16],
    expected_frame_size: usize,
) -> Result<()>
Validate G.722 specific parameters

Errors

Returns an error when the frame is empty, has the wrong sample count, or contains an odd number of samples.